[−][src]Macro debug_here::debug_here
The debug here macro. Just invoke this macro somewhere in your
source, and when your program reaches it a terminal running
rust-gdb or rust-lldb will launch.
If you want to force a specific debugger backend, you can write
debug_here!(gdb) or debug_here!(lldb).